[][src]Enum cast::Error

pub enum Error {
    Infinite,
    NaN,
    Overflow,
    Underflow,
}

Cast errors

Variants

Infinite

Infinite value casted to a type that can only represent finite values

NaN

NaN value casted to a type that can't represent a NaN value

Overflow

Source value is greater than the maximum value that the destination type can hold

Underflow

Source value is smaller than the minimum value that the destination type can hold