[−][src]Enum cast::Error
Cast errors
Variants
Infinite value casted to a type that can only represent finite values
NaN value casted to a type that can't represent a NaN value
Source value is greater than the maximum value that the destination type can hold
Source value is smaller than the minimum value that the destination type can hold